%% ReadPRT.m
% import BrainVoyager PRT files and save the result in a matlab structure called PRT in the source directory
% prt = ReadPRT
%   it includes the following ouput variables:
%       1. resolution - PRT resolution in msec or Volumes
%       2. NoCond - number of conditions in PRT
%       3. Weights - whether weights are saved in PRT
%       4. Cond - with Condition Names, Number of Condition Intervals, Condition
%       5. Colors, and Condition Intervals specified in the resolution defined in "resolution"
% Note: Please avoid any empty PRT conditions!
%last adapted by Judith Eck, 2021-12-10

function prt = ReadPRT

clear
clc

[prtfile, prtdir] = uigetfile('*.prt', 'Select the PRT from the respective run');

fid = fopen([prtdir, prtfile]);
PRT = textscan(fid, '%s'); PRT = PRT{1};

prt.prtfilename = prtfile;
temp = dir([prtdir, prtfile]);
prt.prtfiledate = temp.date;
clear temp

prt.resolution = cell2mat(PRT(find(ismember(PRT,'ResolutionOfTime:'))+1));
prt.NoCond = str2double(PRT(find(ismember(PRT,'NrOfConditions:'))+1));
prt.Weights = str2double(PRT(find(ismember(PRT,'ParametricWeights:'))+1));
prt.Cond(1).CondName = cell2mat(PRT(find(ismember(PRT,'NrOfConditions:'))+2));
CondInd(1) = find(ismember(PRT,'NrOfConditions:'))+2;
ColorInd = find(ismember(PRT,'Color:'));

if prt.NoCond > 1
    for i = 1:prt.NoCond-1
        prt.Cond(i+1).CondName = cell2mat(PRT(ColorInd(i)+4));
        CondInd(i+1) = ColorInd(i)+4;
    end
end
clear i

for i = 1: prt.NoCond
    prt.Cond(i).CondIntervals = str2double(PRT(CondInd(i)+1));
    for c = 1 : 3
        prt.Cond(i).CondColors(1,c) = str2double(PRT(ColorInd(i)+c));
    end
    
    if prt.Weights == 1
        weights = 1;
    else
        weights = 0;
    end
    counter = 1;
    for int = 1:prt.Cond(i).CondIntervals
        prt.Cond(i).CondOnOffsets(int,1) = str2double(PRT(CondInd(i)+1+counter));
        prt.Cond(i).CondOnOffsets(int,2) = str2double(PRT(CondInd(i)+1+counter+1));
        counter = counter + 2 + weights;
    end
end

save([prtdir, prtfile(1:end-4),'_prt.mat'],'prt');
clearvars -except prt

%% Plot the PRT
h1 = figure('Color',[1 1 1]);
title('Experimental Protocol');
xlabel(prt.resolution); ylabel('');
hold;
for p = 1: prt.NoCond
    for c = 1 : size(prt.Cond(p).CondOnOffsets,1)
        rectangle('Position',[prt.Cond(p).CondOnOffsets(c,1),0,(prt.Cond(p).CondOnOffsets(c,2)-prt.Cond(p).CondOnOffsets(c,1))+1, 10],'FaceColor',prt.Cond(p).CondColors/255, 'EdgeColor', 'none');
    end
    plot2(p) = line(NaN,NaN,'LineWidth',2,'LineStyle','-','Color',prt.Cond(p).CondColors/255); % rectangles cannot have a legend, therefore invisible lines with the same Color properties are plotted which are used for legend assignment
    legendInfo{p} = strrep(prt.Cond(p).CondName,'_',' ');
end
legend(plot2,legendInfo)